==> hexo-theme-solitude-2.0.10.tgz: package/README_zh-Hant.md <==
[English](README.md)丨[简体中文](README_zh-Hans.md)丨繁体中文

<div align="center">

  <h1>Solitude</h1>

  一款優雅的 Hexo 主題，支援懶載入、PWA、Latex 以及多種評論系統。

   主題設計由 [@张洪Heo](https://github.com/zhheo) 全權授權

![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?style=for-the-badge)
![license](https://img.shields.io/github/license/everfu/hexo-theme-solitude?color=FF5531&style=for-the-badge)
[![Stars](https://img.shields.io/github/stars/everfu/hexo-theme-solitude?style=for-the-badge)](https://github.com/everfu/hexo-theme-solitude/stargazers)
[![NPM all downloads](https://img.shields.io/npm/dy/hexo-theme-solitude?color=white&style=for-the-badge)](https://www.npmjs.com/package/hexo-theme-solitude)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white&style=for-the-badge)
![node version](https://img.shields.io/badge/node-14.0.0+-white?logo=node.js&logoColor=white&style=for-the-badge)

![page view](https://komarev.com/ghpvc/?username=hexo-theme-solitude&abbreviated=true&base=12345&style=for-the-badge)
[![discord](https://img.shields.io/discord/1266610921942548553?style=for-the-badge&logo=discord&label=discord&logoColor=white)](https://discord.gg/HZXAnK4Sut)
![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains&style=for-the-badge)

[文档](https://solitude.js.org/)丨[預覽](https://solitude.js.org/preview/zh/)

</div>

<div style="width: 80%; margin: 0 auto">

![Screenshot](.github/screenshot.avif)

</div>

## 特性

- 頁面懶載入（Pjax）、圖片懶載入（LazyLoad）、離線應用（PWA）
- 評論(Twikoo、Waline、Valine、Artalk、Giscus)，支援雙評論
- 晝夜切換（ColorMode）
- 燈箱（medium-zoom、fancybox）
- 數學公式（Latex）
- 特色頁面：即刻短文、我的裝備、在線工具、音樂館、友鏈魚塘、相冊頁、豆瓣頁、留言彈幕頁。
- 文章功能：AI 摘要、代碼高亮。

## Todo

- [x] 首页文章列表三列显示
- [x] btns 外挂标签

## 應用

1. 使用 NPM 包進行安裝
      ```bash
      npm i hexo-theme-solitude
      ```
2. 應用主題
      ```yaml
      theme: solitude
      ```

前往 [文檔](https://solitude.js.org/) 獲取更多資訊。

## 贊助者

<div align="center">

[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/W7W1YSMOK)

</div>

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg'/>
  </a>
</p>

## 社區

[![Discord](https://img.shields.io/discord/1266610921942548553?style=for-the-badge&logo=discord&label=discord&logoColor=white)](https://discord.gg/HZXAnK4Sut)
[![QQ 群](https://img.shields.io/badge/QQ%20群-948375336-FFD700?logo=Tencent-QQ&logoColor=white&style=for-the-badge)](https://qm.qq.com/q/mxfomMvJPG)

## 版權

[MIT](./LICENSE) License &copy; 2023-至今 [Efu](https://github.com/everfu)

==> hexo-theme-solitude-2.0.11.tgz: package/README_zh-Hant.md <==
[English](README.md)丨[简体中文](README_zh-Hans.md)丨繁体中文

<div align="center">

  <h1>Solitude</h1>

  一款優雅的 Hexo 主題，支援懶載入、PWA、Latex 以及多種評論系統。

   主題設計由 [@张洪Heo](https://github.com/zhheo) 全權授權

![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?style=for-the-badge)
![license](https://img.shields.io/github/license/everfu/hexo-theme-solitude?color=FF5531&style=for-the-badge)
[![Stars](https://img.shields.io/github/stars/everfu/hexo-theme-solitude?style=for-the-badge)](https://github.com/everfu/hexo-theme-solitude/stargazers)
[![NPM all downloads](https://img.shields.io/npm/dy/hexo-theme-solitude?color=white&style=for-the-badge)](https://www.npmjs.com/package/hexo-theme-solitude)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white&style=for-the-badge)
![node version](https://img.shields.io/badge/node-14.0.0+-white?logo=node.js&logoColor=white&style=for-the-badge)

![page view](https://komarev.com/ghpvc/?username=hexo-theme-solitude&abbreviated=true&base=12345&style=for-the-badge)
[![discord](https://img.shields.io/discord/1266610921942548553?style=for-the-badge&logo=discord&label=discord&logoColor=white)](https://discord.gg/HZXAnK4Sut)
![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains&style=for-the-badge)

[文档](https://solitude.js.org/)丨[預覽](https://solitude.js.org/preview/zh/)丨[作者](https://blog.everfu.cn/)

</div>

<div style="width: 80%; margin: 0 auto">

![Screenshot](.github/screenshot.avif)

</div>

## 特性

- 頁面懶載入（Pjax）、圖片懶載入（LazyLoad）、離線應用（PWA）
- 評論(Twikoo、Waline、Valine、Artalk、Giscus)，支援雙評論
- 晝夜切換（ColorMode）
- 燈箱（medium-zoom、fancybox）
- 數學公式（Latex）
- 特色頁面：即刻短文、我的裝備、在線工具、音樂館、友鏈魚塘、相冊頁、豆瓣頁、留言彈幕頁。
- 文章功能：AI 摘要、代碼高亮。

## Todo

- [x] 首页文章列表三列显示
- [x] btns 外挂标签

## 應用

1. 使用 NPM 包進行安裝
      ```bash
      npm i hexo-theme-solitude
      ```
2. 應用主題
      ```yaml
      theme: solitude
      ```

前往 [文檔](https://solitude.js.org/) 獲取更多資訊。

## 贊助者

<div align="center">

[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/W7W1YSMOK)

</div>

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg'/>
  </a>
</p>

## 社區

[![Discord](https://img.shields.io/discord/1266610921942548553?style=for-the-badge&logo=discord&label=discord&logoColor=white)](https://discord.gg/HZXAnK4Sut)
[![QQ 群](https://img.shields.io/badge/QQ%20群-948375336-FFD700?logo=Tencent-QQ&logoColor=white&style=for-the-badge)](https://qm.qq.com/q/mxfomMvJPG)

## 版權

[MIT](./LICENSE) License &copy; 2023-至今 [Efu](https://github.com/everfu)
